---
title: Settings
---

### Settings

This section will go over how to utilize the settings values you have defined.

#### Setting Interface

This section will go over the `\Anomaly\SettingsModule\Setting\Contract\SettingInterface` class.

##### SettingInterface::field()

The `field` method returns the field type instance for the value or `null` if the value's field no longer exists.

###### Returns: `\Anomaly\Streams\Platform\Addon\FieldType\FieldType` or `null`

###### Example

```php
$setting = $settings->get('anomaly.module.files::max_upload_size');

if ($field = $setting->field()) {
    echo $field->getValue();
}
```

#### Setting Repository

This section will go over the `\Anomaly\SettingsModule\Setting\Contract\SettingRepositoryInterface` class.

##### SettingRepositoryInterface::get()

The `get` method returns the setting instance.

###### Returns: `\Anomaly\SettingsModule\Setting\Contract\SettingInterface`

###### Arguments

| Key  | Required | Type   | Default | Description      |
| ---- | -------- | ------ | ------- | ---------------- |
| $key | true     | string | none    | The setting key. |

###### Example

```php
$max = $settings->value('anomaly.module.files::max_upload_size');

echo $max->getValue();
```

##### SettingRepositoryInterface::set()

The `set` method allows you to set a setting value.

> Values are passed through the setting's field **modifier**.{.tip}

###### Returns: `boolean`

###### Arguments

| Key    | Required | Type   | Default | Description        |
| ------ | -------- | ------ | ------- | ------------------ |
| $key   | true     | string | none    | The setting key.   |
| $value | true     | mixed  | none    | The setting value. |

###### Example

```php
$settings->set('anomaly.module.files::max_upload_size', 32);
```

##### SettingRepositoryInterface::value()

The `value` method returns the value as the setting field type normally would with `getType`.

###### Returns: `mixed`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$key

</td>

<td>

true

</td>

<td>

string

</td>

<td>

none

</td>

<td>

The setting key.

</td>

</tr>

<tr>

<td>

$default

</td>

<td>

false

</td>

<td>

mixed

</td>

<td>

null

</td>

<td>

The default value.

</td>

</tr>

</tbody>

</table>

###### Example

```php
$value = $settings->value('anomaly.module.files::max_upload_size', 2);
```

##### SettingRepositoryInterface::presenter()

The `presenter` method returns the setting value's field type presenter or `null` if the value's field no longer exists.

###### Returns: `\Anomaly\Streams\Platform\Addon\FieldType\FieldTypePresenter` or `null`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$key

</td>

<td>

true

</td>

<td>

string

</td>

<td>

none

</td>

<td>

The setting key.

</td>

</tr>

</tbody>

</table>
